@@ -66,7 +66,7 @@ pub struct RegisterBlock {
     #[doc = "0x7c - rtc configure register"]
     pub rtc_bias_conf: crate::Reg<rtc_bias_conf::RTC_BIAS_CONF_SPEC>,
     #[doc = "0x80 - rtc configure register"]
-    pub rtc_reg: crate::Reg<rtc_reg::RTC_REG_SPEC>,
+    pub rtc: crate::Reg<rtc::RTC_SPEC>,
     #[doc = "0x84 - rtc configure register"]
     pub rtc_pwc: crate::Reg<rtc_pwc::RTC_PWC_SPEC>,
     #[doc = "0x88 - rtc configure register"]
@@ -281,10 +281,10 @@ pub mod rtc_sdio_conf;
 pub type RTC_BIAS_CONF = crate::Reg<rtc_bias_conf::RTC_BIAS_CONF_SPEC>;
 #[doc = "rtc configure register"]
 pub mod rtc_bias_conf;
-#[doc = "RTC_REG register accessor: an alias for `Reg<RTC_REG_SPEC>`"]
-pub type RTC_REG = crate::Reg<rtc_reg::RTC_REG_SPEC>;
+#[doc = "RTC register accessor: an alias for `Reg<RTC_SPEC>`"]
+pub type RTC = crate::Reg<rtc::RTC_SPEC>;
 #[doc = "rtc configure register"]
-pub mod rtc_reg;
+pub mod rtc;
 #[doc = "RTC_PWC register accessor: an alias for `Reg<RTC_PWC_SPEC>`"]
 pub type RTC_PWC = crate::Reg<rtc_pwc::RTC_PWC_SPEC>;
 #[doc = "rtc configure register"]
